@@ -23,8 +23,8 @@
 #include <kxzfilter.h>
 
 #include "zlib.h"
+#include <ctime> // time()
 #include <memory>
-#include <time.h> // time()
 
 #if HAVE_OPENSSL_SUPPORT
 #include <openssl/evp.h>
@@ -38,8 +38,6 @@
 /////////////////////////// K7Zip //////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////
 
-#define BUFFER_SIZE 8 * 1024
-
 static const unsigned char k7zip_signature[6] = {'7', 'z', 0xBC, 0xAF, 0x27, 0x1C};
 // static const unsigned char XZ_HEADER_MAGIC[6] = { 0xFD, '7', 'z', 'X', 'Z', 0x00 };
 
@@ -71,20 +69,20 @@ static quint32 lzma2_dic_size_from_prop(int p)
 
 /* clang-format on*/
 
-#define FILE_ATTRIBUTE_READONLY 1
-#define FILE_ATTRIBUTE_HIDDEN 2
-#define FILE_ATTRIBUTE_SYSTEM 4
-#define FILE_ATTRIBUTE_DIRECTORY 16
-#define FILE_ATTRIBUTE_ARCHIVE 32
-#define FILE_ATTRIBUTE_DEVICE 64
-#define FILE_ATTRIBUTE_NORMAL 128
-#define FILE_ATTRIBUTE_TEMPORARY 256
-#define FILE_ATTRIBUTE_SPARSE_FILE 512
-#define FILE_ATTRIBUTE_REPARSE_POINT 1024
-#define FILE_ATTRIBUTE_COMPRESSED 2048
-#define FILE_ATTRIBUTE_OFFLINE 0x1000
-#define FILE_ATTRIBUTE_ENCRYPTED 0x4000
-#define FILE_ATTRIBUTE_UNIX_EXTENSION 0x8000 /* trick for Unix */
+// #define FILE_ATTRIBUTE_READONLY 1
+// #define FILE_ATTRIBUTE_HIDDEN 2
+// #define FILE_ATTRIBUTE_SYSTEM 4
+constexpr quint32 FILE_ATTRIBUTE_DIRECTORY = 16;
+constexpr quint32 FILE_ATTRIBUTE_ARCHIVE = 32;
+// #define FILE_ATTRIBUTE_DEVICE 64
+// #define FILE_ATTRIBUTE_NORMAL 128
+// #define FILE_ATTRIBUTE_TEMPORARY 256
+// #define FILE_ATTRIBUTE_SPARSE_FILE 512
+// #define FILE_ATTRIBUTE_REPARSE_POINT 1024
+// #define FILE_ATTRIBUTE_COMPRESSED 2048
+// #define FILE_ATTRIBUTE_OFFLINE 0x1000
+// #define FILE_ATTRIBUTE_ENCRYPTED 0x4000
+constexpr quint32 FILE_ATTRIBUTE_UNIX_EXTENSION = 0x8000; /* trick for Unix */
 
 enum HeaderType {
     kEnd,
@@ -197,7 +195,7 @@ public:
      * Returns the content of this file.
      * Call data() with care (only once per file), this data isn't cached.
      */
-    QByteArray data() const override;
+    [[nodiscard]] QByteArray data() const override;
 
     /*!
      * This method returns QIODevice (internal class: KLimitedIODevice)
@@ -209,7 +207,7 @@ public:
      * The returned device auto-opens (in readonly mode), no need to open it.
      * Returns the QIODevice of the file
      */
-    QIODevice *createDevice() const override;
+    [[nodiscard]] QIODevice *createDevice() const override;
 
 private:
     const QByteArray m_data;
@@ -252,25 +250,16 @@ QIODevice *K7ZipFileEntry::createDevice() const
 class FileInfo
 {
 public:
-    FileInfo()
-        : size(0)
-        , attributes(0)
-        , crc(0)
-        , attribDefined(false)
-        , crcDefined(false)
-        , hasStream(false)
-        , isDir(false)
-    {
-    }
+    FileInfo() = default;
 
     QString path;
-    quint64 size;
-    quint32 attributes;
-    quint32 crc;
-    bool attribDefined;
-    bool crcDefined;
-    bool hasStream;
-    bool isDir;
+    quint64 size = 0;
+    quint32 attributes = 0;
+    quint32 crc = 0;
+    bool attribDefined = false;
+    bool crcDefined = false;
+    bool hasStream = false;
+    bool isDir = false;
 };
 
 class Folder
@@ -281,7 +270,7 @@ public:
     public:
         FolderInfo() = default;
 
-        bool isSimpleCoder() const
+        [[nodiscard]] bool isSimpleCoder() const
         {
             return (numInStreams == 1) && (numOutStreams == 1);
         }
@@ -292,22 +281,18 @@ public:
         quint64 methodID = 0;
     };
 
-    Folder()
-        : unpackCRCDefined(false)
-        , unpackCRC(0)
-    {
-    }
+    Folder() = default;
 
     ~Folder() = default;
 
     Q_DISABLE_COPY(Folder)
 
-    quint64 getUnpackSize() const
+    [[nodiscard]] quint64 getUnpackSize() const
     {
         if (unpackSizes.isEmpty()) {
             return 0;
         }
-        for (int i = unpackSizes.size() - 1; i >= 0; i--) {
+        for (qsizetype i = unpackSizes.size() - 1; i >= 0; i--) {
             if (findBindPairForOutStream(i) < 0) {
                 return unpackSizes.at(i);
             }
@@ -315,16 +300,16 @@ public:
         return 0;
     }
 
-    int getNumOutStreams() const
+    [[nodiscard]] int getNumOutStreams() const
     {
         int result = 0;
-        for (int i = 0; i < folderInfos.size(); i++) {
-            result += folderInfos.at(i).numOutStreams;
+        for (const FolderInfo &folderInfo : folderInfos) {
+            result += folderInfo.numOutStreams;
         }
         return result;
     }
 
-    quint32 getCoderInStreamIndex(quint32 coderIndex) const
+    [[nodiscard]] quint32 getCoderInStreamIndex(quint32 coderIndex) const
     {
         quint32 streamIndex = 0;
         for (quint32 i = 0; i < coderIndex; i++) {
@@ -333,7 +318,7 @@ public:
         return streamIndex;
     }
 
-    quint32 getCoderOutStreamIndex(quint32 coderIndex) const
+    [[nodiscard]] quint32 getCoderOutStreamIndex(quint32 coderIndex) const
     {
         quint32 streamIndex = 0;
         for (quint32 i = 0; i < coderIndex; i++) {
@@ -342,7 +327,7 @@ public:
         return streamIndex;
     }
 
-    int findBindPairForInStream(size_t inStreamIndex) const
+    [[nodiscard]] int findBindPairForInStream(size_t inStreamIndex) const
     {
         for (int i = 0; i < inIndexes.size(); i++) {
             if (inIndexes[i] == inStreamIndex) {
@@ -352,7 +337,7 @@ public:
         return -1;
     }
 
-    int findBindPairForOutStream(size_t outStreamIndex) const
+    [[nodiscard]] int findBindPairForOutStream(size_t outStreamIndex) const
     {
         for (int i = 0; i < outIndexes.size(); i++) {
             if (outIndexes[i] == outStreamIndex) {
@@ -362,7 +347,7 @@ public:
         return -1;
     }
 
-    int findPackStreamArrayIndex(size_t inStreamIndex) const
+    [[nodiscard]] int findPackStreamArrayIndex(size_t inStreamIndex) const
     {
         for (int i = 0; i < packedStreams.size(); i++) {
             if (packedStreams[i] == inStreamIndex) {
@@ -396,9 +381,9 @@ public:
         }
     }
 
-    bool isEncrypted() const
+    [[nodiscard]] bool isEncrypted() const
     {
-        for (int i = folderInfos.size() - 1; i >= 0; i--) {
+        for (qsizetype i = folderInfos.size() - 1; i >= 0; i--) {
             if (folderInfos.at(i).methodID == k_AES) {
                 return true;
             }
@@ -408,8 +393,8 @@ public:
 
     // bool CheckStructure() const;
 
-    bool unpackCRCDefined;
-    quint32 unpackCRC;
+    bool unpackCRCDefined = false;
+    quint32 unpackCRC = 0;
     QList<FolderInfo> folderInfos;
     QList<quint64> inIndexes;
     QList<quint64> outIndexes;
@@ -420,16 +405,8 @@ public:
 class Q_DECL_HIDDEN K7Zip::K7ZipPrivate
 {
 public:
-    K7ZipPrivate(K7Zip *parent)
+    explicit K7ZipPrivate(K7Zip *parent)
         : q(parent)
-        , packPos(0)
-        , numPackStreams(0)
-        , buffer(nullptr)
-        , pos(0)
-        , end(0)
-        , headerSize(0)
-        , countSize(0)
-        , m_currentFile(nullptr)
     {
     }
 
@@ -458,8 +435,8 @@ public:
     QList<quint64> startPositions;
     QList<int> fileInfoPopIDs;
 
-    quint64 packPos;
-    quint64 numPackStreams;
+    quint64 packPos = 0;
+    quint64 numPackStreams = 0;
     QList<quint64> packSizes;
     QList<quint64> unpackSizes;
     QList<bool> digestsDefined;
@@ -469,16 +446,16 @@ public:
 
     QString password;
 
-    const char *buffer;
-    quint64 pos;
-    quint64 end;
-    quint64 headerSize;
-    quint64 countSize;
+    const char *buffer = nullptr;
+    quint64 pos = 0;
+    quint64 end = 0;
+    quint64 headerSize = 0;
+    quint64 countSize = 0;
 
     // Write
     QByteArray header;
     QByteArray outData; // Store data in this buffer before compress and write in archive.
-    K7ZipFileEntry *m_currentFile;
+    K7ZipFileEntry *m_currentFile = nullptr;
     QList<KArchiveEntry *> m_entryList;
 
     void clear()
@@ -534,7 +511,7 @@ public:
     QByteArray readAndDecodePackedStreams(bool readMainStreamInfo = true);
 
     // Write
-    void createItemsFromEntities(const KArchiveDirectory *, const QString &, QByteArray &);
+    void createItemsFromEntities(const KArchiveDirectory *dir, const QString &path, QByteArray &data);
     void writeByte(unsigned char b);
     void writeNumber(quint64 value);
     void writeBoolVector(const QList<bool> &boolVector);
@@ -544,7 +521,7 @@ public:
     void writeAlignedBoolHeader(const QList<bool> &v, int numDefined, int type, unsigned itemSize);
     void writeUInt64DefVector(const QList<quint64> &v, const QList<bool> &defined, int type);
     void writeFolder(const Folder *folder);
-    void writePackInfo(quint64 dataOffset, QList<quint64> &packedSizes, QList<bool> &packedCRCsDefined, QList<quint32> &packedCRCs);
+    void writePackInfo(quint64 dataOffset, const QList<quint64> &packedSizes, const QList<bool> &packedCRCsDefined, const QList<quint32> &packedCRCs);
     void writeUnpackInfo(const QList<Folder *> &folderItems);
     void writeSubStreamsInfo(const QList<quint64> &unpackSizes, const QList<bool> &digestsDefined, const QList<quint32> &digests);
     void writeHeader(quint64 &headerOffset);
@@ -581,14 +558,10 @@ void K7Zip::setPassword(const QString &password) {
 
 bool K7Zip::passwordNeeded() const
 {
-    for (int i = 0; i < d->folders.size(); i++) {
-        const Folder *folder = d->folders.at(i);
-        if (folder && folder->isEncrypted()) {
-            return true;
-        }
-    }
-
-    return false;
+    return std::ranges::any_of(std::as_const(d->folders),
+        [](const Folder *folder) {
+            return folder && folder->isEncrypted();
+        });
 }
 
 int K7Zip::K7ZipPrivate::readByte()
@@ -766,6 +739,8 @@ void K7Zip::K7ZipPrivate::readHashDigests(int numItems, QList<bool> &digestsDefi
     }
 }
 
+constexpr auto kMaxCoders = std::numeric_limits<int>::max() / sizeof(Folder::FolderInfo);
+
 Folder *K7Zip::K7ZipPrivate::folderItem()
 {
     if (!buffer) {
@@ -773,12 +748,16 @@ Folder *K7Zip::K7ZipPrivate::folderItem()
     }
 
     auto folder = std::make_unique<Folder>();
-    int numCoders = readNumber();
+    const quint64 numCoders = readNumber();
+    if (numCoders > kMaxCoders) {
+        // Limit the amount of folderInfos to a "reasonable" amount
+        return nullptr;
+    }
     folder->folderInfos.reserve(numCoders);
 
     quint64 numInStreamsTotal = 0;
     quint64 numOutStreamsTotal = 0;
-    for (int i = 0; i < numCoders; ++i) {
+    for (quint64 coderI = 0; coderI < numCoders; ++coderI) {
         // BYTE
         //    {
         //      0:3 CodecIdSize
@@ -819,7 +798,7 @@ Folder *K7Zip::K7ZipPrivate::folderItem()
         // if (There Are Attributes)
         if ((coderInfo & 0x20) != 0) {
             const int propertiesSize = readNumber();
-            for (int i = 0; i < propertiesSize; ++i) {
+            for (int propertyI = 0; propertyI < propertiesSize; ++propertyI) {
                 const int property = readByte();
                 if (property == -1) {
                     return nullptr;
@@ -1130,12 +1109,9 @@ bool K7Zip::K7ZipPrivate::readSubStreamsInfo()
 }
 
 #define TICKSPERSEC 10000000
-#define TICKSPERMSEC 10000
 #define SECSPERDAY 86400
 #define SECSPERHOUR 3600
 #define SECSPERMIN 60
-#define EPOCHWEEKDAY 1 /* Jan 1, 1601 was Monday */
-#define DAYSPERWEEK 7
 #define DAYSPERQUADRICENTENNIUM (365 * 400 + 97)
 #define DAYSPERNORMALQUADRENNIUM (365 * 4 + 1)
 #define TICKS_1601_TO_1970 (SECS_1601_TO_1970 * TICKSPERSEC)
@@ -1434,18 +1410,14 @@ const quint32 kTopValue = (1 << kNumTopBits);
 
 class RangeDecoder
 {
-    int pos;
+    int pos = 0;
 
 public:
     QByteArray stream;
-    quint32 range;
-    quint32 code;
+    quint32 range = 0xFFFFFFFF;
+    quint32 code = 0;
 
-    RangeDecoder(const QByteArray &s)
-        : pos(0)
-        , stream(s)
-        , range(0xFFFFFFFF)
-        , code(0)
+    explicit RangeDecoder(const QByteArray &s) : stream(s)
     {
         for (int i = 0; i < 5; i++) {
             code = (code << 8) | readByte();
@@ -1911,7 +1883,7 @@ QByteArray K7Zip::K7ZipPrivate::readAndDecodePackedStreams(bool readMainStreamIn
                     delete filter;
                     return QByteArray();
                 }
-                int uncompressedBytes = outBuffer.size() - filter->outBufferAvailable();
+                const qsizetype uncompressedBytes = outBuffer.size() - filter->outBufferAvailable();
 
                 // append the uncompressed data to inflate buffer
                 inflatedDataTmp.append(outBuffer.data(), uncompressedBytes);
@@ -2033,8 +2005,8 @@ void K7Zip::K7ZipPrivate::writeBoolVector(const QList<bool> &boolVector)
 {
     int b = 0;
     short mask = 0x80;
-    for (int i = 0; i < boolVector.size(); i++) {
-        if (boolVector[i]) {
+    for (const bool boolValue : boolVector) {
+        if (boolValue) {
             b |= mask;
         }
         mask >>= 1;
@@ -2082,12 +2054,12 @@ void K7Zip::K7ZipPrivate::writeAlignedBoolHeader(const QList<bool> &v, int numDe
     writeByte(0);
 }
 
-void K7Zip::K7ZipPrivate::writeUInt64DefVector(const QList<quint64> &v, const QList<bool> &defined, int type)
+void K7Zip::K7ZipPrivate::writeUInt64DefVector(const QList<quint64> &v, const QList<bool> &definedVector, int type)
 {
     int numDefined = 0;
 
-    for (int i = 0; i < defined.size(); i++) {
-        if (defined[i]) {
+    for (const bool defined : definedVector) {
+        if (defined) {
             numDefined++;
         }
     }
@@ -2096,10 +2068,10 @@ void K7Zip::K7ZipPrivate::writeUInt64DefVector(const QList<quint64> &v, const QL
         return;
     }
 
-    writeAlignedBoolHeader(defined, numDefined, type, 8);
+    writeAlignedBoolHeader(definedVector, numDefined, type, 8);
 
-    for (int i = 0; i < defined.size(); i++) {
-        if (defined[i]) {
+    for (int i = 0; i < definedVector.size(); i++) {
+        if (definedVector[i]) {
             writeUInt64(v[i]);
         }
     }
@@ -2134,7 +2106,7 @@ void K7Zip::K7ZipPrivate::writeHashDigests(const QList<bool> &digestsDefined, co
     }
 }
 
-void K7Zip::K7ZipPrivate::writePackInfo(quint64 dataOffset, QList<quint64> &packedSizes, QList<bool> &packedCRCsDefined, QList<quint32> &packedCRCs)
+void K7Zip::K7ZipPrivate::writePackInfo(quint64 dataOffset, const QList<quint64> &packedSizes, const QList<bool> &packedCRCsDefined, const QList<quint32> &packedCRCs)
 {
     if (packedSizes.isEmpty()) {
         return;
@@ -2144,8 +2116,8 @@ void K7Zip::K7ZipPrivate::writePackInfo(quint64 dataOffset, QList<quint64> &pack
     writeNumber(packedSizes.size());
     writeByte(kSize);
 
-    for (int i = 0; i < packedSizes.size(); i++) {
-        writeNumber(packedSizes[i]);
+    for (const quint64 packedSize : packedSizes) {
+        writeNumber(packedSize);
     }
 
     writeHashDigests(packedCRCsDefined, packedCRCs);
@@ -2156,8 +2128,7 @@ void K7Zip::K7ZipPrivate::writePackInfo(quint64 dataOffset, QList<quint64> &pack
 void K7Zip::K7ZipPrivate::writeFolder(const Folder *folder)
 {
     writeNumber(folder->folderInfos.size());
-    for (int i = 0; i < folder->folderInfos.size(); i++) {
-        const Folder::FolderInfo &info = folder->folderInfos.at(i);
+    for (const Folder::FolderInfo &info : folder->folderInfos) {
         {
             size_t propsSize = info.properties.size();
 
@@ -2207,8 +2178,8 @@ void K7Zip::K7ZipPrivate::writeFolder(const Folder *folder)
     }
 
     if (folder->packedStreams.size() > 1) {
-        for (int i = 0; i < folder->packedStreams.size(); i++) {
-            writeNumber(folder->packedStreams[i]);
+        for (const quint64 packedStream : folder->packedStreams) {
+            writeNumber(packedStream);
         }
     }
 }
@@ -2225,8 +2196,8 @@ void K7Zip::K7ZipPrivate::writeUnpackInfo(const QList<Folder *> &folderItems)
     writeNumber(folderItems.size());
     {
         writeByte(0);
-        for (int i = 0; i < folderItems.size(); i++) {
-            writeFolder(folderItems[i]);
+        for (const Folder *folderItem : folderItems) {
+            writeFolder(folderItem);
         }
     }
 
@@ -2234,8 +2205,8 @@ void K7Zip::K7ZipPrivate::writeUnpackInfo(const QList<Folder *> &folderItems)
     int i;
     for (i = 0; i < folderItems.size(); i++) {
         const Folder *folder = folderItems[i];
-        for (int j = 0; j < folder->unpackSizes.size(); j++) {
-            writeNumber(folder->unpackSizes.at(j));
+        for (const quint64 unpackSize : folder->unpackSizes) {
+            writeNumber(unpackSize);
         }
     }
 
@@ -2257,11 +2228,11 @@ void K7Zip::K7ZipPrivate::writeSubStreamsInfo(const QList<quint64> &unpackSizes,
 {
     writeByte(kSubStreamsInfo);
 
-    for (int i = 0; i < numUnpackStreamsInFolders.size(); i++) {
-        if (numUnpackStreamsInFolders.at(i) != 1) {
+    for (const quint64 numUnpackStreamsInFolder : std::as_const(numUnpackStreamsInFolders)) {
+        if (numUnpackStreamsInFolder != 1) {
             writeByte(kNumUnpackStream);
-            for (int j = 0; j < numUnpackStreamsInFolders.size(); j++) {
-                writeNumber(numUnpackStreamsInFolders.at(j));
+            for (const quint64 j : std::as_const(numUnpackStreamsInFolders)) {
+                writeNumber(j);
             }
             break;
         }
@@ -2269,9 +2240,9 @@ void K7Zip::K7ZipPrivate::writeSubStreamsInfo(const QList<quint64> &unpackSizes,
 
     bool needFlag = true;
     int index = 0;
-    for (int i = 0; i < numUnpackStreamsInFolders.size(); i++) {
-        for (quint32 j = 0; j < numUnpackStreamsInFolders.at(i); j++) {
-            if (j + 1 != numUnpackStreamsInFolders.at(i)) {
+    for (const quint64 numUnpackStreamsInFolder : std::as_const(numUnpackStreamsInFolders)) {
+        for (quint32 j = 0; j < numUnpackStreamsInFolder; j++) {
+            if (j + 1 != numUnpackStreamsInFolder) {
                 if (needFlag) {
                     writeByte(kSize);
                 }
@@ -2364,8 +2335,8 @@ QByteArray K7Zip::K7ZipPrivate::encodeStream(QList<quint64> &packSizes, QList<Fo
 void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
 {
     quint64 packedSize = 0;
-    for (int i = 0; i < packSizes.size(); ++i) {
-        packedSize += packSizes[i];
+    for (const quint64 packSize : std::as_const(packSizes)) {
+        packedSize += packSize;
     }
 
     headerOffset = packedSize;
@@ -2383,8 +2354,7 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
         QList<quint64> unpackFileSizes;
         QList<bool> digestsDefined;
         QList<quint32> digests;
-        for (int i = 0; i < fileInfos.size(); i++) {
-            const FileInfo *file = fileInfos.at(i);
+        for (const FileInfo *file : std::as_const(fileInfos)) {
             if (!file->hasStream) {
                 continue;
             }
@@ -2409,8 +2379,8 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
         /* ---------- Empty Streams ---------- */
         QList<bool> emptyStreamVector;
         int numEmptyStreams = 0;
-        for (int i = 0; i < fileInfos.size(); i++) {
-            if (fileInfos.at(i)->hasStream) {
+        for (const FileInfo *fileInfo : std::as_const(fileInfos)) {
+            if (fileInfo->hasStream) {
                 emptyStreamVector.append(false);
             } else {
                 emptyStreamVector.append(true);
@@ -2461,8 +2431,8 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
 
         int numDefined = 0;
         size_t namesDataSize = 0;
-        for (int i = 0; i < fileInfos.size(); i++) {
-            const QString &name = fileInfos.at(i)->path;
+        for (const FileInfo *fileInfo : std::as_const(fileInfos)) {
+            const QString &name = fileInfo->path;
             numDefined++;
             namesDataSize += (name.length() + 1) * 2;
         }
@@ -2474,8 +2444,8 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
             writeByte(kName);
             writeNumber(namesDataSize);
             writeByte(0);
-            for (int i = 0; i < fileInfos.size(); i++) {
-                const QString &name = fileInfos.at(i)->path;
+            for (const FileInfo *fileInfo : std::as_const(fileInfos)) {
+                const QString &name = fileInfo->path;
                 for (int t = 0; t < name.length(); t++) {
                     wchar_t c = name[t].toLatin1();
                     writeByte((unsigned char)c);
@@ -2497,8 +2467,8 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
         QList<bool> boolVector;
         int numDefined = 0;
         boolVector.reserve(fileInfos.size());
-        for (int i = 0; i < fileInfos.size(); i++) {
-            bool defined = fileInfos.at(i)->attribDefined;
+        for (const FileInfo *fileInfo : std::as_const(fileInfos)) {
+            bool defined = fileInfo->attribDefined;
             boolVector.append(defined);
             if (defined) {
                 numDefined++;
@@ -2507,8 +2477,7 @@ void K7Zip::K7ZipPrivate::writeHeader(quint64 &headerOffset)
 
         if (numDefined > 0) {
             writeAlignedBoolHeader(boolVector, numDefined, kAttributes, 4);
-            for (int i = 0; i < fileInfos.size(); i++) {
-                const FileInfo *file = fileInfos.at(i);
+            for (const FileInfo *file : std::as_const(fileInfos)) {
                 if (file->attribDefined) {
                     writeUInt32(file->attributes);
                 }
@@ -2702,8 +2671,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
         type = d->readByte();
     } else {
-        for (int i = 0; i < d->folders.size(); ++i) {
-            Folder *folder = d->folders.at(i);
+        for (const Folder *folder : std::as_const(d->folders)) {
             d->unpackSizes.append(folder->getUnpackSize());
             d->digestsDefined.append(folder->unpackCRCDefined);
             d->digests.append(folder->unpackCRC);
@@ -2729,12 +2697,12 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
     // TODO Explore a way to be able to support more files.
     // Right now we limit to 1000 million files
-    static const qsizetype MAX_FILE_NUMBER = 1000 * 1000 * 1000;
-    const qsizetype numFiles = fileNumFiles;
-    if (numFiles > MAX_FILE_NUMBER) {
-        setErrorString(tr("Archive has %1 files which is more than the supported amount (%2)").arg(numFiles).arg(MAX_FILE_NUMBER));
+    static const int MAX_FILE_NUMBER = 1000 * 1000 * 1000;
+    if (fileNumFiles > MAX_FILE_NUMBER) {
+        setErrorString(tr("Archive has %1 files which is more than the supported amount (%2)").arg(fileNumFiles).arg(MAX_FILE_NUMBER));
         return false;
     }
+    const int numFiles = static_cast<int>(fileNumFiles);
     for (int i = 0; i < numFiles; ++i) {
         d->fileInfos.append(new FileInfo);
     }
@@ -2763,8 +2731,8 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
             switch (type) {
             case kEmptyStream: {
                 d->readBoolVector(numFiles, emptyStreamVector);
-                for (int i = 0; i < emptyStreamVector.size(); ++i) {
-                    if (emptyStreamVector[i]) {
+                for (const bool emptyStreamValue : std::as_const(emptyStreamVector)) {
+                    if (emptyStreamValue) {
                         numEmptyStreams++;
                     }
                 }
@@ -2970,7 +2938,7 @@ bool K7Zip::openArchive(QIODevice::OpenMode mode)
 
         KArchiveEntry *e;
         QString entryName;
-        int index = fileInfo->path.lastIndexOf(QLatin1Char('/'));
+        const qsizetype index = fileInfo->path.lastIndexOf(QLatin1Char('/'));
         if (index == -1) {
             entryName = fileInfo->path;
         } else {
@@ -3112,8 +3080,8 @@ bool K7Zip::closeArchive()
     d->packSizes.append(encodedData.size());
 
     int numUnpackStream = 0;
-    for (int i = 0; i < d->fileInfos.size(); ++i) {
-        if (d->fileInfos.at(i)->hasStream) {
+    for (const FileInfo *fileInfo : std::as_const(d->fileInfos)) {
+        if (fileInfo->hasStream) {
             numUnpackStream++;
         }
     }
@@ -3143,8 +3111,8 @@ bool K7Zip::closeArchive()
         d->writePackInfo(headerOffset, packSizes, emptyDefined, emptyCrcs);
         d->writeUnpackInfo(folders);
         d->writeByte(kEnd);
-        for (int i = 0; i < packSizes.size(); i++) {
-            headerOffset += packSizes.at(i);
+        for (const quint64 packSize : std::as_const(packSizes)) {
+            headerOffset += packSize;
         }
         qDeleteAll(folders);
     }
@@ -3215,7 +3183,7 @@ bool K7Zip::doPrepareWriting(const QString &name,
     // QString fileName( name );
     // In some files we can find dir/./file => call cleanPath
     QString fileName(QDir::cleanPath(name));
-    int i = name.lastIndexOf(QLatin1Char('/'));
+    const qsizetype i = name.lastIndexOf(QLatin1Char('/'));
     if (i != -1) {
         QString dir = name.left(i);
         fileName = name.mid(i + 1);
@@ -3268,7 +3236,7 @@ bool K7Zip::doWriteDir(const QString &name,
     }
 
     KArchiveDirectory *parentDir = rootDir();
-    int i = dirName.lastIndexOf(QLatin1Char('/'));
+    const qsizetype i = dirName.lastIndexOf(QLatin1Char('/'));
     if (i != -1) {
         QString dir = name.left(i);
         dirName = name.mid(i + 1);
@@ -3304,7 +3272,7 @@ bool K7Zip::doWriteSymLink(const QString &name,
     KArchiveDirectory *parentDir = rootDir();
     // In some files we can find dir/./file => call cleanPath
     QString fileName(QDir::cleanPath(name));
-    int i = name.lastIndexOf(QLatin1Char('/'));
+    const qsizetype i = name.lastIndexOf(QLatin1Char('/'));
     if (i != -1) {
         QString dir = name.left(i);
         fileName = name.mid(i + 1);
